@@ -19,8 +19,6 @@ KEY_UE_FEEDBACK = 'feedback'
 KEY_UE_GRADING = 'grading'
 KEY_UE_PRE_EVAL_EX = 'pre_eval_ex_%02d'
 
-TAG_ABGABE = 'abgabe_%d'
-
 
 class TeamIndex:
 
@@ -110,13 +108,12 @@ def checkout(ctx, group, ue: int):
     uebung_path = ep2.uebung_dir()
     errors = []
 
-    with open(students_file, 'r') as infile:  # read students and create entries in attendance file
-        reader = csv.DictReader(infile, students_csv_fieldnames(), KEY_INVALID, strict=True)
+    student_list = group.student_info()
+    tag = ep2.get_ue_tag(ue)
 
-        headers = next(reader, None)
-        if not validate_headers(headers):
-            click.secho('Malformed file: %s. Invalid headers!' % students_file, fg='red')
-            exit(1)
+    click.echo("Checking out " + tag)
+
+    with click.progressbar(student_list.values(), label="Clone/Pull") as reader:  # read students and create entries in attendance file
 
         for row in reader:
             if KEY_INVALID in row:
@@ -131,12 +128,9 @@ def checkout(ctx, group, ue: int):
             repo = ep2.ue_repo(student_id)
 
             # clone or pull repo
-            clone_result = ep2.clone_or_update(os.path.join(uebung_path, student_id), repo, TAG_ABGABE % ue)
+            clone_result = ep2.clone_or_update(os.path.join(uebung_path, student_id), repo, tag)
             if clone_result.is_err():
-                errors += [clone_result.value]
-
-        infile.seek(0)
-        next(reader, None)  # skip header row
+                errors += [student_id + ": " + clone_result.value]
 
         if not os.path.exists(pre_eval_file):
 
@@ -152,7 +146,7 @@ def checkout(ctx, group, ue: int):
 
                 writer.writeheader()
 
-                for row in reader:
+                for row in student_list.values():
                     # no validation required, as file is the same
 
                     student_id = row[KEY_STUDENT_ID]
